==> tinyvisor-1.4.tar.gz: tinyvisor/vmm/core/vt_msr.h <==
/*
 * Copyright (c) 2007, 2008 University of Tsukuba
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 3. Neither the name of the University of Tsukuba nor the names of its
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _CORE_VT_MSR_H
#define _CORE_VT_MSR_H

#include "types.h"

struct vt_msr_entry {
	u32 index;
	u32 reserved;
	u64 data;
} __attribute__ ((packed));

struct vt_msr {
	struct vt_msr_entry *vmm;
	struct vt_msr_entry *guest;
	int count;
	int efer, star, lstar, cstar, fmask, kerngs;
};

void vt_msr_update_lma (void);
int vt_add_guest_msr (ulong index);
bool vt_read_guest_msr (int i, u64 *data);
bool vt_write_guest_msr (int i, u64 data);
bool vt_read_msr (u32 msrindex, u64 *msrdata);
bool vt_write_msr (u32 msrindex, u64 msrdata);
void vt_msr_init (void);

#endif

==> tinyvisor-1.7.tar.gz: tinyvisor/vmm/core/vt_msr.h <==
/*
 * Copyright (c) 2007, 2008 University of Tsukuba
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 3. Neither the name of the University of Tsukuba nor the names of its
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _CORE_VT_MSR_H
#define _CORE_VT_MSR_H

#include "types.h"

struct vt_msr_entry {
	u32 index;
	u32 reserved;
	u64 data;
} __attribute__ ((packed));

struct vt_msr {
	struct vt_msr_entry *vmm;
	struct vt_msr_entry *guest;
	int count;
	u64 efer, star, lstar, cstar, fmask, kerngs;
};

struct vt_msrbmp {
	void *msrbmp;
	u64 msrbmp_phys;
};

void vt_msr_own_process_msrs (void);
void vt_msr_update_lma (void);
int vt_add_guest_msr (ulong index);
bool vt_read_guest_msr (int i, u64 *data);
bool vt_write_guest_msr (int i, u64 data);
bool vt_read_msr (u32 msrindex, u64 *msrdata);
bool vt_write_msr (u32 msrindex, u64 msrdata);
void vt_msrpass (u32 msrindex, bool wr, bool pass);
void vt_msr_init (void);

#endif
